import os
from dotenv import load_dotenv

load_dotenv()

SUPABASE_URL: str = os.getenv('SUPABASE_URL')
SUPABASE_KEY: str = os.getenv('SUPABASE_KEY')
OPENAI_API_KEY: str = os.getenv('OPENAI_API_KEY')

if not SUPABASE_URL or not SUPABASE_KEY:
    raise ValueError("SUPABASE_URL and SUPABASE_KEY must be set in the .env file")


SYSTEM_PROMPT = """你是一位專業的閩南語轉錄為中文校對助理，專門處理有關長照/日照中心的台語對話轉錄。
你的任務是：
1. 確保以下專業術語在台語拼音轉換時的準確性：廁所、幫我、身體、什麼時候、現在、有點、冷、會不會、車、昨晚、血壓、需要、量血壓、早餐、午餐、晚餐、主任、早安、午安、晚安、聯絡簿、等車、交通車、國小、什麼、看什麼、可以、什麼意思、垃圾、冷氣、電風扇、喝水、倒垃圾、上廁所、上班、看孫子、走路、起床、幾點、毛筆、冰箱、哥哥、妹妹、菜市場、夜市、工作、老闆。
2. 在必要時添加適當的標點符號，如句號、逗號
3. 使用台灣的繁體中文，確保語言表達符合台灣的用語習慣。
4. 只更正明顯的錯誤或改善可讀性，不要改變原文的意思或結構。
5. 不要回答問題、解釋概念或添加任何不在原文中的信息。
6. 如果原文是一個問句，保持它的問句形式，不要提供答案。

請只根據提供的原文進行必要的更正，不要添加或刪除任何實質性內容。在修正時，請特別注意上下文，確保修正後的詞語符合整句話的語境。"""

CORRECT_TERMS = ["廁所", "幫我", "什麼時候", "身體", "現在", "有點", "冷", "會不會", "車", "昨晚", "血壓", "需要", "量血壓", "早餐", "午餐", "晚餐", "主任", "早安", "午安", "晚安", "聯絡簿", "等車", "交通車", "幼兒園", "國小", "國中", "高中", "大學", "日照中心", "吃飯", "垃圾", "冷氣", "孫子", "電風扇", "喝水", "倒垃圾", "上廁所", "上班", "看孫子", "聯繫", "走路", "起床", "幾點", "毛筆", "電視", "冰箱", "廚房", "可以", "哥哥", "妹妹", "夜市", "工作", "老闆", "什麼"]

ERROR_CORRECTION = {
    '跨三回' : '看什麼', 
    '畫沙小' : '看三小', 
    '高通車' : '交通車', 
    '的東西搞' : '什麼時候到', 
    '倒三餐' : '', 
    '幫我看什麼嗎' : '幫我', 
    '今天中午回來吃什麼?' : '今天午餐吃甚麼?', 
    '本授抵多維' : '廁所在哪裡?', 
    '本書的國語' : '廁所在哪裡?', 
    '本週底得位' : '廁所在哪裡?', 
    '本授地當位' : '廁所在哪裡?', 
    '本說底都會' : '廁所在哪裡?', 
}

